@@ -9,7 +9,6 @@
 #include <libosso.h>
 #include <pthread.h>
 
-
 G_BEGIN_DECLS
 
 
@@ -32,7 +31,8 @@ G_BEGIN_DECLS
 
 
 #define SERVER "http://xurrency.com/api/"
-#define PORT "80"
+//#define SERVER "http://www.google.com/"
+//#define PORT "81"
 #define BUFFER_SIZE (256*1024)
 
 
@@ -81,6 +81,7 @@ typedef struct {
         int update_interval;
         time_t last_update;
         int not_updated;
+        int currency_changed;
 } currency_set;
 
 
@@ -106,6 +107,7 @@ struct _CurrencyWidget
            
             // Currency set for plugin
             currency_set *curset;
+
             
             gchar *id;
             int timeout;
