@@ -34,6 +34,7 @@ extern char *countries[];
 
 
 gboolean as_update_values(CurrencyWidget *desktop_plugin);
+gboolean as_update_values_once(CurrencyWidget *desktop_plugin);
 
 static GtkWidget *update_ui(CurrencyWidget *plug) {
 
@@ -110,9 +111,12 @@ enum {
 gboolean
 callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_plugin )
 {
-
     int i,j;
-
+    
+    if (   pthread_mutex_lock(&desktop_plugin->mutex) != 0 ) {
+        fprintf(stderr, "could not lock mutex");
+    }
+    
     desktop_plugin->curset->currency_changed = 0;
 
     GtkWidget *dialog;
@@ -279,6 +283,9 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pan), pan_content);
     gtk_container_add(GTK_CONTAINER(content), pan); 
 
+    if (  pthread_mutex_unlock(&desktop_plugin->mutex) != 0 ) {
+        fprintf(stderr, "could not unlock mutex");
+    } 
 
     /* Show */
     gtk_widget_show_all(dialog);
@@ -287,6 +294,7 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
         int result = gtk_dialog_run(GTK_DIALOG(dialog));
         // Get values and update gui
         if ( result == GTK_RESPONSE_ACCEPT) {
+             pthread_mutex_lock(&desktop_plugin->mutex);
 
             for ( j = 0; j < 2; j++ ) {
 
@@ -358,8 +366,9 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
                     exit(EXIT_FAILURE);
                     break;
             }
+            pthread_mutex_unlock(&desktop_plugin->mutex);
 
-            as_update_values(desktop_plugin);
+            g_timeout_add(100,as_update_values_once,desktop_plugin);
             gtk_widget_destroy(dialog);
 
             break;
@@ -372,24 +381,82 @@ callback( GtkWidget *widget,   GdkEventButton* event, CurrencyWidget *desktop_pl
             gtk_widget_destroy(dialog);
             break;
         }
-    } } 
+    }
+} 
 
 
 
 void thread_update_values(CurrencyWidget *desktop_plugin) {
-    pthread_mutex_lock(&desktop_plugin->mutex);
-    get_values_json(&desktop_plugin->curset);
+
+    if ( pthread_mutex_lock(&desktop_plugin->mutex) != 0 ) {
+        fprintf(stderr, "could not lock mutex");
+    }
+
+    get_values_json(&desktop_plugin);
+    
+    if ( desktop_plugin->curset->not_updated == 1 && desktop_plugin->curset->currency_changed == 1) {
+        strcpy (desktop_plugin->curset->active_currency->value, "offline");
+    }  
+
+    update_ui(desktop_plugin);
+
+    if ( pthread_mutex_unlock(&desktop_plugin->mutex) != 0 ) {
+        fprintf(stderr, "could not unlock mutex");
+    }
+
+    pthread_exit(0);
+}
+  
+void sy_update_values(CurrencyWidget *desktop_plugin) {
+    get_values_json(&desktop_plugin);
+    if ( pthread_mutex_lock(&desktop_plugin->mutex) != 0 ) {
+        fprintf(stderr, "could not lock mutex");
+    }
+    
     if ( desktop_plugin->curset->not_updated == 1 && desktop_plugin->curset->currency_changed == 1) {
         strcpy (desktop_plugin->curset->active_currency->value, "offline");
     } 
     
     update_ui(desktop_plugin);
-    pthread_mutex_unlock(&desktop_plugin->mutex);
-    pthread_exit(0);
+    
+    if (  pthread_mutex_unlock(&desktop_plugin->mutex) != 0 ) {
+        fprintf(stderr, "could not unlock mutex");
+    }
 }
-   
+
 gboolean as_update_values(CurrencyWidget *desktop_plugin) {
   
+    
+
+    pthread_t tid;
+    int error;
+            
+    if ( pthread_mutex_lock(&desktop_plugin->mutex) != 0 ) {
+        fprintf(stderr, "could not lock  mutex");
+    }
+
+    set_gui_update_mode(desktop_plugin);
+    
+    if ( pthread_mutex_unlock(&desktop_plugin->mutex) != 0) {
+        fprintf(stderr, "could not unlock mutex");
+    }
+
+    error = pthread_create(&tid, NULL, thread_update_values, desktop_plugin);
+
+    if ( error  != 0 ) {
+         fprintf(stderr, "Could not create thread : %d\n", error);
+     }
+    
+    pthread_detach(tid);
+    
+
+    return TRUE;
+}
+
+gboolean as_update_values_once(CurrencyWidget *desktop_plugin) {
+  
+
+
     pthread_t tid;
     int error;
             
@@ -397,16 +464,16 @@ gboolean as_update_values(CurrencyWidget *desktop_plugin) {
     set_gui_update_mode(desktop_plugin);
     pthread_mutex_unlock(&desktop_plugin->mutex); 
 
-
     error = pthread_create(&tid, NULL, thread_update_values, desktop_plugin);
 
     if ( error  != 0 ) {
-        fprintf(stderr, "Could not create thread : %d\n", error);
+      fprintf(stderr, "Could not create thread : %d\n", error);
     }
     
     pthread_detach(tid);
+    
 
-    return TRUE;
+    return FALSE;
 }
 
 void about_dialog() {
@@ -448,7 +515,7 @@ void about_dialog() {
     gtk_text_buffer_insert_pixbuf (GTK_TEXT_BUFFER(text_buffer), &iter, pixbuf);
 
     char tmp_text[1000];
-    sprintf(tmp_text, "\n\nCurrency Exchange Widget version 0.1.2\n\nCurrency Exchange Widget displays the current exchange rate\nof the selected currency.\n\nThis software is released under the GPL license.\n\nSource of exchange rate data: www.xurrency.com\nSource of flag icons: www.icondrawer.com\n\nwww.binop.com\n2010 %lc binop consulting group\n", 0xa9 );
+    sprintf(tmp_text, "\n\nCurrency Exchange Widget version 0.1.3\n\nCurrency Exchange Widget displays the current exchange rate\nof the selected currency.\n\nThis software is released under the GPL license.\n\nSource of exchange rate data: www.xurrency.com\nSource of flag icons: www.icondrawer.com\n\nwww.binop.com\n2010 %lc binop consulting group\n", 0xa9 );
 
 
     gtk_text_buffer_insert(text_buffer, &iter, tmp_text, -1);
